pub enum Content {
Normal,
Fit,
Flex,
Wrap {
wrap_spacing: Option<f32>,
},
}Variants
Normal
Default layout, children are stacked along the direction axis.
Fit
Resize children to evenly fit the available space along the direction axis.
Flex
Let children use Size::Flex to grow proportionally to fill the available space.
Wrap
Wrap children to the next line or column when they exceed the available space, with an optional gap between wrapped lines.
Implementations